//= QCMM2000 Include File ====================================

//===========================================================================
//  Please do not use global variables or arrays in the include file of
//  instrument drivers that will be submitted for inclusion into the
//  LabWindows Instrument Driver Library.
//===========================================================================

#ifndef __QCMM2000_HEADER
#define __QCMM2000_HEADER

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

//***************************************************************************
//= Instrument Specific Error/Warning Codes
//***************************************************************************

#define QCMM2000_SUCCESS			0
#define QCMM2000_ERR				(-2147483647L-1)  /* 0x80000000 */

#define QCMM2000_WARN_BASE			(0x3FFC0A00L)
#define QCMM2000_WARN_DATA_TIMEOUT	(QCMM2000_WARN_BASE+0x00L)
#define QCMM2000_WARN_RESP_CRC_BAD	(QCMM2000_WARN_BASE+0x02L)

#define QCMM2000_ERR_BASE			(QCMM2000_ERR+0x3FFC0A00L)
#define QCMM2000_ERR_CMD_CRC_BAD	(QCMM2000_ERR_BASE+0x01L)
#define QCMM2000_ERR_INV_COMMAND	(QCMM2000_ERR_BASE+0x02L)
#define QCMM2000_ERR_DATA_RNG_ERR	(QCMM2000_ERR_BASE+0x03L)
#define QCMM2000_ERR_ROM_BAD		(QCMM2000_ERR_BASE+0x04L)
#define QCMM2000_ERR_RAM_BAD		(QCMM2000_ERR_BASE+0x05L)
#define QCMM2000_ERR_DATA_BAD		(QCMM2000_ERR_BASE+0x06L)
#define QCMM2000_ERR_RS232_ERROR	(QCMM2000_ERR_BASE+0x07L)
#define QCMM2000_ERR_CHAN_TEMP_BAD	(QCMM2000_ERR_BASE+0x08L)
#define QCMM2000_ERR_INV_CMD_RESP	(QCMM2000_ERR_BASE+0x09L)
#define QCMM2000_ERR_INV_DATA_RESP	(QCMM2000_ERR_BASE+0x0AL)
#define QCMM2000_ERR_INITIALIZATION	(QCMM2000_ERR_BASE+0x0BL)
#define QCMM2000_ERR_UNKNOWN_ERR	(QCMM2000_ERR_BASE+0x0FL)

#ifdef _CVI_DLL_
#define DLL_DIRECTION	DLLEXPORT
#else
#define DLL_DIRECTION	DLLIMPORT
#endif

// define Channel Type flags

#define	PRT_SENSOR		0x01
#define	HEAT_PUMP		0x02
#define	EFFUSION_HEATER	0x40
#define VALID_CHANNEL	0x80

//***************************************************************************
//= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions)
//***************************************************************************

// Initialization
// Initialize the instrument and set to default configuration.

int DLL_DIRECTION CVIFUNC QCMM2000_init (int comPort, int baudRate, int parity, 
		int dataBits, int stopBits );


// Close
// This function takes the instrument offline.

int DLL_DIRECTION CVIFUNC QCMM2000_close ( void );


// Application Functions
// This class contains high-level, test and measurement routines.
// These examples call other instrument driver functions to
// configure, start, and read from the instrument.

int DLL_DIRECTION CVIFUNC QCMM2000_getChanData ( int channelOn[], int heaterOn[], 
		float chanTimer[], float chanTemp[], float chanFreq[], float chanHVolts[] );
void DLL_DIRECTION CVIFUNC QCMM2000_getChannelState ( int chan, int *channelOn );
void DLL_DIRECTION CVIFUNC QCMM2000_getChanTempSetPt ( int chan, float *tempSetPt );
void DLL_DIRECTION CVIFUNC QCMM2000_getChanTempRate ( int chan, float *tempRate );
void DLL_DIRECTION CVIFUNC QCMM2000_getHeaterState ( int chan, int *heaterOn );
void DLL_DIRECTION CVIFUNC QCMM2000_getUnitChanData ( int chan, unsigned int *chanType, 
		char chanLabel[], float *maxTempSetPt, long *thermConst );
void DLL_DIRECTION CVIFUNC QCMM2000_getUnitData ( char serialNbr[], char unitName[] );
void DLL_DIRECTION CVIFUNC QCMM2000_getUnitStatus ( int *unitStatus );
void DLL_DIRECTION CVIFUNC QCMM2000_getHeatVoltRange ( int chan, float *voltsTop, 
		float *voltsBot );
void DLL_DIRECTION CVIFUNC QCMM2000_getHeatDACRange ( int chan, float *dacZer, 
		float *dacTop, float *dacBot );
void DLL_DIRECTION CVIFUNC QCMM2000_setChanTempLimits ( int chan, float tempLimitHi, 
		float tempLimitLo );
void DLL_DIRECTION CVIFUNC QCMM2000_setChannelState ( int chan, int channelOn );
int DLL_DIRECTION CVIFUNC QCMM2000_setChanTempSetPt ( int chan, float *tempSetPt );
int DLL_DIRECTION CVIFUNC QCMM2000_setChanTempRate ( int chan, float *tempRate );


// Configuration Functions
// This class of functions configures the instrument by setting
// acquisition and system configuration parameters.

int DLL_DIRECTION CVIFUNC QCMM2000_setMode ( int desiredMode );
int DLL_DIRECTION CVIFUNC QCMM2000_setCRC ( int crcFlag );


// Action/Status Functions
// This class of functions begins or terminates an acquisition. It also 
// provides functions which allow the user to determine the current 
// status of the instrument.

int DLL_DIRECTION CVIFUNC QCMM2000_go ( void );
int DLL_DIRECTION CVIFUNC QCMM2000_halt ( void );
int DLL_DIRECTION CVIFUNC QCMM2000_killHeater ( int chan );
int DLL_DIRECTION CVIFUNC QCMM2000_query ( void );


// Utility Functions
// This class of functions provides lower level functions to communicate 
// with the instrument, and change instrument parameters.

int DLL_DIRECTION CVIFUNC QCMM2000_reset ( void );
void DLL_DIRECTION CVIFUNC QCMM2000_errorQuery ( int *errorCode, char errorMsg[] );
void DLL_DIRECTION CVIFUNC QCMM2000_errorMessage ( int statusCode, char errorMsg[] );
void DLL_DIRECTION CVIFUNC QCMM2000_revisionQuery ( char driverRev[], char firmwareVer[] );


// The following prototypes are only defined when compiling the QCMM2000 dll.

#ifdef _CVI_DLL_

// Data Functions
// This class of functions transfers data to or from the instrument.

int CVIFUNC QCMM2000_writeChanTempRate ( int chan, float *tempRate );
int CVIFUNC QCMM2000_writeChanTempSetPt ( int chan, float *tempSetPt );
int CVIFUNC QCMM2000_readUnitData ( void );
int CVIFUNC QCMM2000_readFirmwareVer ( void );
int CVIFUNC QCMM2000_readUnitStatus( void );
int CVIFUNC QCMM2000_readHeatVoltRange ( int chan );
int CVIFUNC QCMM2000_readHeatDACRange ( int chan );


// Utility Functions
// This class of functions provides lower level functions to communicate 
// with the instrument, and change instrument parameters.

void CVIFUNC QCMM2000_initData ( void );
int CVIFUNC QCMM2000_saveChanData ( char readBuffer[] );
int CVIFUNC QCMM2000_read ( char readBuffer[], int sizeBuffer );
int CVIFUNC QCMM2000_write ( char cmdString[] );
int CVIFUNC QCMM2000_writeCmdWaitResp ( int cmdID, char cmdData[] );
int CVIFUNC QCMM2000_writeCmdReadData ( int cmdID, char cmdData[], 
		char readBuffer[], int sizeBuffer );
#endif

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

//***************************************************************************
//=== END INCLUDE FILE ======================================================
//***************************************************************************

#endif
